
/* ====================================================================
   Copyright 2002-2004   Apache Software Foundation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */
        

package org.apache.poi.hslf.record;

import org.apache.poi.util.LittleEndian;

/**
 * If we come across a record we know has children of (potential)
 *  interest, but where the record itself is boring, we create one
 *  of these. It allows us to get at the children, but not much else
 *
 * @author Nick Burch
 */

public class DummyRecordWithChildren extends Record
{
	private Record[] _children;
	private byte[] _contents;
	private long _type;

	/** 
	 * Create a new holder for a boring record with children
	 */
	protected DummyRecordWithChildren(byte[] source, int start, int len) {
		_contents = new byte[len];
		System.arraycopy(source,start,_contents,0,len);
		_type = LittleEndian.getUShort(_contents,2);

		// Find our children
		_children = Record.findChildRecords(_contents,8,len-8);
	}

	/** 
	 * We're not an atom, that's our whole point
	 */
	public boolean isAnAtom() { return false; }

	/**
	 * Return the value we were given at creation
	 */
	public long getRecordType() { return _type; }

	/** 
	 * Return any children 
	 */
	public Record[] getChildRecords() { return _children; }

	/**
	 * Fetch the byte representation of this record. Really the
	 *  only use of this record, so it can be written back to disk
	 */
	protected byte[] getByteRepresentation() { return _contents; }
}
