
/* ====================================================================
   Copyright 2002-2004   Apache Software Foundation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */
        

package org.apache.poi.hslf.record;

import org.apache.poi.util.LittleEndian;

/**
 * If we come across a record we don't know about, we create one of
 *  these. It allows us to keep track of what it contains, so we can
 *  write it back out to disk unchanged
 *
 * @author Nick Burch
 */

public class UnknownRecordPlaceholder extends Record
{
	private byte[] _contents;
	private long _type;

	/** 
	 * Create a new holder for a record we don't grok
	 */
	protected UnknownRecordPlaceholder(byte[] source, int start, int len) {
		_contents = new byte[len];
		System.arraycopy(source,start,_contents,0,len);
		_type = LittleEndian.getUShort(_contents,2);
	}

	/** 
	 * We pretend to be an atom, as we don't process the contents
	 */
	public boolean isAnAtom() { return true; }

	/**
	 * Return the value we were given at creation
	 */
	public long getRecordType() { return _type; }

	/** 
	 * As we're an atom-like record, always return null
	 */
	public Record[] getChildRecords() { return null; }

	/**
	 * Fetch the byte representation of this record. Really the
	 *  only use of this record, so it can be written back to disk
	 */
	protected byte[] getByteRepresentation() { return _contents; }
}
